Module pipeline

Module pipeline 

Structs

Pipeline
Ordered list of transformers run in registration order. Boxed + Send + Sync so a Pipeline can be shared across worker threads.

Traits

Transformer
One AST-to-AST pass. transform takes &self so a transformer is cheap to share across threads or reuse across files.