NodeAction

Enum NodeAction 

pub enum NodeAction {
    Keep,
    KeepSkipChildren,
    Replace(Vec<Node>),
    Remove,
}
Result of visiting one node. Walker consumes this when iterating the parent’s children Vec.

Variants



Keep

Walker recurses into this node’s children.



KeepSkipChildren

Node stays in place but its children are not visited.



Replace(Vec<Node>)

Splice these nodes into the parent’s children at the current index. Replacements are NOT re-visited (prevents infinite loops on transformers that produce nodes matching their own pattern).



Remove

Drop this node from the parent’s children.